@@ -1,12 +1,11 @@
 package MooseX::Role::Timer;
-
-use Moose::Role;
+$MooseX::Role::Timer::VERSION = '0.05';
+#use Any::Moose '::Role';
+use Moo::Role;
 use Time::HiRes;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
-
 =head1 NAME
 
 MooseX::Role::Timer - Measure times with your object.
@@ -14,7 +13,7 @@ MooseX::Role::Timer - Measure times with your object.
 =head1 SYNOPSIS
 
  package Demo;
- use Moose;
+ use Moose; # or Any::Moose
  with 'MooseX::Role::Timer';
 
  sub BUILD {
@@ -40,7 +39,7 @@ whatever actions take.
 
 =cut
 
-has '_timers' => ( is=>'rw', isa=>'HashRef', default=>sub{{}} );
+has '_timers' => ( is=>'rw', default=>sub{{}} );
 
 =over 4
 
@@ -61,7 +60,7 @@ sub start_timer {
 
 =item stop_timer($name)
 
-Stop timer $name. Could be startet again to cumulatively measure time.
+Stop timer $name. Could be started again to cumulatively measure time.
 
 =cut
 
@@ -132,7 +131,7 @@ your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Michael Langner, all rights reserved.
+Copyright 2015 Michael Langner, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
